@@ -4,17 +4,11 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Fout",
     "New note" : "Nuwe nota",
-    "Help" : "Hulp",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Daar is ongestoorde veranderinge. Indien die bladsy gesluit word sal alle veranderinge geskrap word!",
-    "Insert image" : "Voer beeld in",
     "File extension for new notes" : "Lêeruitbreiding vir nuwe notas",
+    "Insert image" : "Voer beeld in",
     "All notes" : "Alle notas",
     "Categories" : "Kategorieë",
-    "Loading …" : "Laai …",
-    "Today" : "Vandag",
-    "Yesterday" : "Gister",
-    "This week" : "Vandeesweek",
-    "Rename" : "Hernoem",
     "Details" : "Besonderhede",
     "Delete note" : "Skrap nota",
     "Remove from favorites" : "Verwyder uit gunstelinge",
@@ -22,6 +16,10 @@ OC.L10N.register(
     "Use current version" : "Gebruik huidige weergawe",
     "Edit" : "Wysig",
     "Preview" : "Voorskou",
+    "Loading …" : "Laai …",
+    "Today" : "Vandag",
+    "Yesterday" : "Gister",
+    "This week" : "Vandeesweek",
     "Category" : "Kategorie",
     "Uncategorized" : "Ongekategorieseer",
     "Saving failed!" : "Stoor het misluk!",
