@@ -4,15 +4,13 @@ OC.L10N.register(
     "Notes" : "Qeydlər",
     "Error" : "Səhv",
     "New note" : "Yeni qeyd",
-    "Help" : "Kömək",
-    "Today" : "Bu gün",
-    "Yesterday" : "Dünən",
-    "Rename" : "Adı dəyiş",
     "Details" : "Detallar",
     "Delete note" : "Qeydi sil",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "Dəyişiklik et",
+    "Today" : "Bu gün",
+    "Yesterday" : "Dünən",
     "Tasks" : "Tapşırıqlar"
 },
 "nplurals=2; plural=(n != 1);");
