@@ -4,15 +4,13 @@ OC.L10N.register(
     "Notes" : "নোট",
     "Error" : "সমস্যা",
     "New note" : "নতুন নোট",
-    "Help" : "সহায়িকা",
-    "Today" : "আজ",
-    "Yesterday" : "গতকাল",
-    "Rename" : "পূনঃনামকরণ",
     "Details" : "বিসতারিত",
     "Delete note" : "নোট মোছ",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "সম্পাদনা",
+    "Today" : "আজ",
+    "Yesterday" : "গতকাল",
     "Tasks" : "কর্ম"
 },
 "nplurals=2; plural=(n != 1);");
