@@ -4,23 +4,21 @@ OC.L10N.register(
     "Notes" : "Nodiadau",
     "Error" : "Gwall",
     "New note" : "Nodyn newydd",
-    "Help" : "Cymorth",
     "Display mode for notes" : "Modd arddangos nodiadau",
     "Open in edit mode" : "Agor yn y modd golygu",
     "Open in preview mode" : "Agor yn y modd rhagolwg",
-    "No notes yet" : "Dim nodiadau eto",
     "All notes" : "Pob nodyn",
-    "Loading …" : "Yn llwytho …",
-    "Today" : "Heddiw",
-    "Yesterday" : "Ddoe",
-    "This week" : "Wythnos yma",
-    "This month" : "Mis yma",
-    "Rename" : "Ailenwi",
+    "No notes yet" : "Dim nodiadau eto",
     "Details" : "Manylion",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "Golygu",
     "Preview" : "Rhagolwg",
+    "Loading …" : "Yn llwytho …",
+    "Today" : "Heddiw",
+    "Yesterday" : "Ddoe",
+    "This week" : "Wythnos yma",
+    "This month" : "Mis yma",
     "Category" : "Categori",
     "Uncategorized" : "Dim categori"
 },
