@@ -4,27 +4,16 @@ OC.L10N.register(
     "Notes" : "Noter",
     "Error" : "Fejl",
     "New note" : "Ny note",
-    "Help" : "Hjælp",
     "Undo Delete" : "Annullér Slet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
-    "Result" : "Resultat",
-    "Action" : "Handling",
-    "Insert image" : "Indsæt billede",
     "Display mode for notes" : "Visningstilstand for noter",
+    "Action" : "Handling",
     "Open in edit mode" : "Åbn i redigeringstilstand",
     "Open in preview mode" : "Åbn forhåndsvisning",
-    "No notes yet" : "Ingen noter endnu",
+    "Insert image" : "Indsæt billede",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
-    "Loading …" : "Indlæser…",
-    "Today" : "I dag",
-    "Yesterday" : "I går",
-    "This week" : "Denne uge",
-    "Last week" : "Sidste uge",
-    "This month" : "Denne måned",
-    "Last month" : "Seneste måned",
-    "Rename" : "Omdøb",
-    "Note's title" : "Notens titel",
+    "No notes yet" : "Ingen noter endnu",
     "Details" : "Detaljer",
     "Delete note" : "Slet note",
     "Remove from favorites" : "Fjernet fra favoritter",
@@ -32,6 +21,13 @@ OC.L10N.register(
     "Use current version" : "Brug aktuelle version",
     "Edit" : "Redigér",
     "Preview" : "Vis eksempel",
+    "Loading …" : "Indlæser…",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
+    "This week" : "Denne uge",
+    "Last week" : "Sidste uge",
+    "This month" : "Denne måned",
+    "Last month" : "Seneste måned",
     "Category" : "Katergori",
     "Uncategorized" : "Udenfor kategori",
     "Saving failed!" : "Kunne ikke gemme!",
