@@ -6,7 +6,7 @@ OC.L10N.register(
     "Error" : "Σφάλμα",
     "New note" : "Νέα σημείωση",
     "Distraction-free notes and writing" : "Χωρίς περιορισμούς σημειώσεις και γραφή",
-    "Help" : "Βοήθεια",
+    "Notes settings" : "Ρυθμίσεις σημειώσεων",
     "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το ιστορικό του διακομιστή Nextcloud.",
     "Deleted {title}" : "Διεγραμμένες {title}",
     "Undo Delete" : "Αναίρεση διαγραφής",
@@ -16,20 +16,18 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Επαναφέρθηκε {number} σημείωση","Επαναφέρθηκαν {number} σημειώσεις"],
     "Write down your thoughts without any distractions." : "Κρατήστε τις σκέψεις σας χωρίς περιορισμούς.",
     "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
-    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
-    "Result" : "Αποτέλεσμα",
-    "Shortcuts" : "Συντομεύσεις",
-    "Action" : "Ενέργεια",
-    "Insert image" : "Εισαγωγή εικόνας",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
-    "Notes settings" : "Ρυθμίσεις σημειώσεων",
     "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
     "Root directory" : "Ριζικός κατάλογος",
     "File extension for new notes" : "Πρόσθετο αρχείου για νέες σημειώσεις",
     "Display mode for notes" : "Λειτουργία εμφάνισης για τις σημειώσεις",
+    "Shortcuts" : "Συντομεύσεις",
+    "Action" : "Ενέργεια",
     "User defined" : "Ορισμένο από τον χρήστη",
     "Open in edit mode" : "Άνοιγμα για επεξεργασία",
     "Open in preview mode" : "Άνοιγμα για προεπισκόπιση",
+    "Insert image" : "Εισαγωγή εικόνας",
+    "All notes" : "Όλες οι σημειώσεις",
+    "Categories" : "Κατηγορίες",
     "No notes yet" : "Δεν υπάρχουν ακόμα σημειώσεις",
     "Upload image" : "Μεταφόρτωση εικόνας",
     "Select an image" : "Επιλέξτε μια εικόνα",
@@ -37,17 +35,6 @@ OC.L10N.register(
     "Wrong image" : "Λάθος εικόνα",
     "The file was not uploaded. Check your server logs." : "Το αρχείο δεν μεταφορτώθηκε. Ελέγξτε τα αρχεία καταγραφής του διακομιστή σας.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Εγκαταστήστε την εφαρμογή στο κινητό σας για πρόσβαση από οπουδήποτε.",
-    "All notes" : "Όλες οι σημειώσεις",
-    "Categories" : "Κατηγορίες",
-    "Loading …" : "Φόρτωση…",
-    "Today" : "Σήμερα",
-    "Yesterday" : "Χθές",
-    "This week" : "Αυτή την εβδομάδα",
-    "Last week" : "Προηγούμενη εβδομάδα",
-    "This month" : "Αυτό το μήνα",
-    "Last month" : "Προηγούμενος μήνας",
-    "Rename" : "Μετονομασία",
-    "Note's title" : "Τίτλος σημειωματάριου",
     "Details" : "Λεπτομέρειες",
     "Delete note" : "Διαγραφή σημείωσης",
     "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
@@ -67,6 +54,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κλίκ για προσπάθεια ξανά.",
     "Update conflict. Click for resolving manually." : "Διένεξη κατά την ενημέρωση. Κάντε κλικ για μη αυτόματη επίλυση.",
     "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
+    "Loading …" : "Φόρτωση…",
+    "Today" : "Σήμερα",
+    "Yesterday" : "Χθές",
+    "This week" : "Αυτή την εβδομάδα",
+    "Last week" : "Προηγούμενη εβδομάδα",
+    "This month" : "Αυτό το μήνα",
+    "Last month" : "Προηγούμενος μήνας",
     "Category" : "Κατηγορία",
     "Uncategorized" : "Χωρίς κατηγορία",
     "Set category" : "Ορίστε κατηγορία",
@@ -77,6 +71,8 @@ OC.L10N.register(
     "Subcategory" : "Υποκατηγορία",
     "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
     "_%n character_::_%n characters_" : ["%n χαρακτήρας","%n χαρακτήρες"],
+    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Μπορείτε να δημιουργήσετε υποκατηγορίες χρησιμοποιώντας το \"/\" ως οριοθέτη μεταξύ της κατηγορίας και της υποκατηγορίας, π.χ. \"{Parent}/{sub}\".",
     "Note not found." : "Δεν βρέθηκε η σημείωση.",
     "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
