@@ -5,17 +5,12 @@ OC.L10N.register(
     "Error" : "Eraro",
     "New note" : "Nova noto",
     "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
-    "Help" : "Helpo",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
-    "Insert image" : "Enmeti bildon",
     "Folder to store your notes" : "Dosiero, en kiu konservi viajn notojn",
     "File extension for new notes" : "Dosiersufikso por novaj notoj",
+    "Insert image" : "Enmeti bildon",
     "All notes" : "Ĉiuj notoj",
     "Categories" : "Kategorioj",
-    "Loading …" : "Ŝargado...",
-    "Today" : "Hodiaŭ",
-    "Yesterday" : "Hieraŭ",
-    "Rename" : "Alinomi",
     "Details" : "Detaloj",
     "Delete note" : "Forigi noton",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
@@ -23,6 +18,9 @@ OC.L10N.register(
     "Use current version" : "Uzi nunan version",
     "Edit" : "Modifi",
     "Preview" : "Antaŭvidi",
+    "Loading …" : "Ŝargado...",
+    "Today" : "Hodiaŭ",
+    "Yesterday" : "Hieraŭ",
     "Category" : "Kategorio",
     "Uncategorized" : "Senkategoria",
     "Saving failed!" : "Konservado malsukcesis!",
