@@ -4,15 +4,19 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nueva nota",
-    "Help" : "Ayuda",
-    "Result" : "Resultado",
-    "Action" : "Acción",
     "Display mode for notes" : "Modo de visualización para notas",
+    "Action" : "Acción",
     "Open in edit mode" : "Abrir en modo editor",
     "Open in preview mode" : "Abrir en modo de vista previa",
-    "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas la notas",
     "Categories" : "Categoría",
+    "No notes yet" : "Aún no hay notas",
+    "Details" : "Detalles",
+    "Delete note" : "Borrar nota",
+    "Remove from favorites" : "Eliminado de favoritos",
+    "Add to favorites" : "Agregar a favoritos",
+    "Edit" : "Editar",
+    "Preview" : "Vista previa",
     "Loading …" : "Cargando …",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
@@ -20,13 +24,6 @@ OC.L10N.register(
     "Last week" : "Semana pasada",
     "This month" : "Este mes",
     "Last month" : "Mes pasado",
-    "Rename" : "Renombrar",
-    "Details" : "Detalles",
-    "Delete note" : "Borrar nota",
-    "Remove from favorites" : "Eliminado de favoritos",
-    "Add to favorites" : "Agregar a favoritos",
-    "Edit" : "Editar",
-    "Preview" : "Vista previa",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
