@@ -4,27 +4,24 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nota nueva",
-    "Help" : "Ayuda",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Result" : "Resultado",
     "Action" : "Acción",
     "Open in edit mode" : "Abrir en modo edición",
     "Open in preview mode" : "Abrir en modo previsualización",
-    "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
-    "Loading …" : "Cargando …",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "This week" : "Esta semana",
-    "This month" : "Este mes",
-    "Rename" : "Renombrar",
+    "No notes yet" : "Aún no hay notas",
     "Details" : "Detalles",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
+    "Loading …" : "Cargando …",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "This week" : "Esta semana",
+    "This month" : "Este mes",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
