@@ -5,21 +5,14 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nota nueva",
     "Distraction-free notes and writing" : "Notas y escritura libre de distracciones",
-    "Help" : "Ayuda",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Result" : "Resultado",
     "Action" : "Acción",
-    "Insert image" : "Añadir imagen",
     "Open in edit mode" : "Abrir en modo edición",
     "Open in preview mode" : "Abrir en modo previsualización",
-    "No notes yet" : "Aún no hay notas",
+    "Insert image" : "Añadir imagen",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "This week" : "Esta semana",
-    "This month" : "Este mes",
-    "Rename" : "Renombrar",
+    "No notes yet" : "Aún no hay notas",
     "Details" : "Detalles",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
@@ -27,6 +20,10 @@ OC.L10N.register(
     "Use current version" : "Usar la versión actual",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "This week" : "Esta semana",
+    "This month" : "Este mes",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
