@@ -4,12 +4,8 @@ OC.L10N.register(
     "Notes" : "Märkmed",
     "Error" : "Viga",
     "New note" : "Uus märge",
-    "Help" : "Abiinfo",
-    "No notes yet" : "Märkmeid veel pole",
     "Categories" : "Kategooriad",
-    "Today" : "Täna",
-    "Yesterday" : "Eile",
-    "Rename" : "Nimeta ümber",
+    "No notes yet" : "Märkmeid veel pole",
     "Details" : "Üksikasjad",
     "Delete note" : "Kustuta märge",
     "Remove from favorites" : "Eemalda lemmikutest",
@@ -17,6 +13,8 @@ OC.L10N.register(
     "Use current version" : "Kasuta praegust versiooni",
     "Edit" : "Redigeeri",
     "Preview" : "Eelvaade",
+    "Today" : "Täna",
+    "Yesterday" : "Eile",
     "Category" : "Kategooria",
     "_%n word_::_%n words_" : ["%n sõna","%n sõna"],
     "Tasks" : "Ülesanded"
