@@ -6,7 +6,7 @@ OC.L10N.register(
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
     "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
-    "Help" : "Ohje",
+    "Notes settings" : "Asetukset",
     "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
     "Deleted {title}" : "Poistettu {title}",
     "Undo Delete" : "Kumoa",
@@ -17,16 +17,18 @@ OC.L10N.register(
     "Basics" : "Perusteet",
     "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
     "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
-    "Markdown" : "Markdown",
-    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
-    "Sequence" : "Merkkijono",
-    "Result" : "Tulos",
-    "Visualized" : "Visalisoitu",
+    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
+    "Root directory" : "Juurihakemisto",
+    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
+    "Display mode for notes" : "Muistiinpanojen esitystapa",
     "Shortcuts" : "Pikanäppäimet",
     "Use shortcuts to quickly navigate this app." : "Käytä pikanäppäimiä nopeaan siirtymiseen sovelluksessa.",
     "Shortcut" : "Pikanäppäin",
     "Action" : "Toiminto",
     "Mobile apps" : "Mobiilisovellukset",
+    "User defined" : "Käyttäjän määrittelemä",
+    "Open in edit mode" : "Avaa muokkaustilassa",
+    "Open in preview mode" : "Avaa esikatselutilassa",
     "CTRL" : "CTRL",
     "Make the selection bold" : "Lihavoi valinta",
     "Make the selection italic" : "Kursivoi valinta",
@@ -42,34 +44,8 @@ OC.L10N.register(
     "Insert link" : "Lisää linkki",
     "Insert image" : "Lisää kuva",
     "Switch between editor and viewer" : "Vaihda muokkaus- ja katselutilan välllä",
-    "bold" : "lihavoitu",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
-    "italic" : "kursivoitu",
-    "strikethrough" : "yliviivattu",
-    "Big header" : "Suuri otsikko",
-    "Medium header" : "Keskikokoinen otsikko",
-    "Small header" : "Pienehkö otsikko",
-    "Tiny header" : "Pieni otsikko",
-    "Generic list item" : "Yleinen listaelementti",
-    "Generic list" : "Yleinen lista",
-    "Numbered list" : "Numeroitu lista",
-    "Link title" : "Linkin otsikko",
-    "link" : "linkki",
-    "Image title" : "Kuvan otsikko",
-    "image" : "kuva",
-    "This is a quote." : "Tämä on lainaus.",
-    "quote" : "lainaus",
-    "code" : "koodi",
-    "Multi line block code" : "Monirivinen koodialue",
-    "Notes settings" : "Asetukset",
-    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
-    "Root directory" : "Juurihakemisto",
-    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
-    "Display mode for notes" : "Muistiinpanojen esitystapa",
-    "User defined" : "Käyttäjän määrittelemä",
-    "Open in edit mode" : "Avaa muokkaustilassa",
-    "Open in preview mode" : "Avaa esikatselutilassa",
-    "Create a sample note with markdown" : "Luo muistiinpanoesimerkki markdownilla",
+    "All notes" : "Kaikki muistiinpanot",
+    "Categories" : "Luokat",
     "No notes yet" : "Ei muistiinpanoja",
     "Upload image" : "Lataa kuva",
     "Select an image" : "Valitse kuva",
@@ -77,19 +53,6 @@ OC.L10N.register(
     "Wrong image" : "Väärä kuva",
     "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Asenna sovellus puhelimeesi käyttääksesi muistiinpanoja missä tahansa.",
-    "Android app: {notes} by {company}" : "Android-sovellus: {notes} by {company}",
-    "iOS app: {notes} by {company}" : "iOS-sovellus: {notes} by {company}",
-    "All notes" : "Kaikki muistiinpanot",
-    "Categories" : "Luokat",
-    "Loading …" : "Ladataan…",
-    "Today" : "Tänään",
-    "Yesterday" : "Eilen",
-    "This week" : "Tällä viikolla",
-    "Last week" : "Viime viikolla",
-    "This month" : "Tässä kuussa",
-    "Last month" : "Viime kuussa",
-    "Rename" : "Nimeä uudelleen",
-    "Note's title" : "Muistiinpanon otsikko",
     "Details" : "Tiedot",
     "Delete note" : "Poista muistiinpano",
     "Remove from favorites" : "Poista suosikeista",
@@ -109,6 +72,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
     "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
     "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
+    "Loading …" : "Ladataan…",
+    "Today" : "Tänään",
+    "Yesterday" : "Eilen",
+    "This week" : "Tällä viikolla",
+    "Last week" : "Viime viikolla",
+    "This month" : "Tässä kuussa",
+    "Last month" : "Viime kuussa",
     "Category" : "Luokka",
     "Uncategorized" : "Luokittelematon",
     "Set category" : "Aseta luokka",
@@ -119,6 +89,8 @@ OC.L10N.register(
     "Subcategory" : "Aliluokka",
     "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
     "_%n character_::_%n characters_" : ["%n merkki","%n merkkiä "],
+    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Voit luoda alikategorioita käyttämällä /-merkkiä eroittimena yläkategorian ja alikategorian välissä esim: \"{parent}/{sub}\".",
     "Note not found." : "Muistiinpanoa ei löytynyt.",
     "Note is locked." : "Muistiinpano on lukittu.",
