@@ -4,20 +4,18 @@ OC.L10N.register(
     "Notes" : "Nòtaichean",
     "Error" : "Mearachd",
     "New note" : "Nòta ùr",
-    "Help" : "Cobhair",
     "Display mode for notes" : "Modh sealladh nan nòtaichean",
     "All notes" : "A h-uile nòta",
+    "Details" : "Mion-fhiosrachadh",
+    "Add to favorites" : "Cuir ris na h-annsachdan",
+    "Edit" : "Deasaich",
+    "Preview" : "Ro-sheall",
     "Today" : "An-diugh",
     "Yesterday" : "An-dè",
     "This week" : "An t-seachdain seo",
     "Last week" : "An t-seachdain seo chaidh",
     "This month" : "Am mìos seo",
     "Last month" : "Am mìos seo chaidh",
-    "Rename" : "Thoir ainm ùr air",
-    "Details" : "Mion-fhiosrachadh",
-    "Add to favorites" : "Cuir ris na h-annsachdan",
-    "Edit" : "Deasaich",
-    "Preview" : "Ro-sheall",
     "Category" : "Roinn-seòrsa",
     "Uncategorized" : "Gun seòrsachadh"
 },
