@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "שגיאה",
     "New note" : "פתק חדש",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
-    "Help" : "עזרה",
     "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
     "Deleted {title}" : "{title} נמחק",
     "Undo Delete" : "ביטול מחיקה",
@@ -16,30 +15,18 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
     "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
     "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
-    "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
-    "Result" : "תוצאה",
-    "Shortcuts" : "קיצורי דרך",
-    "Action" : "פעולה",
-    "Insert image" : "הוספת תמונה",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
     "Display mode for notes" : "מצב תצוגת פתקים",
+    "Shortcuts" : "קיצורי דרך",
+    "Action" : "פעולה",
     "Open in edit mode" : "פתיחה במצב עריכה",
     "Open in preview mode" : "פתיחה במצב תצוגה מקדימה",
-    "No notes yet" : "אין פתקים עדיין",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "יש להתקין את היישומון לטלפון הנייד שלך כדי לגשת לפתקים שלך מכל מקום.",
+    "Insert image" : "הוספת תמונה",
     "All notes" : "כל הפתקים",
     "Categories" : "קטגוריות",
-    "Loading …" : "בטעינה",
-    "Today" : "היום",
-    "Yesterday" : "אתמול",
-    "This week" : "השבוע",
-    "Last week" : "שבוע שעבר",
-    "This month" : "החודש",
-    "Last month" : "חודש שעבר",
-    "Rename" : "שינוי שם",
-    "Note's title" : "הכותרת של הפתק",
+    "No notes yet" : "אין פתקים עדיין",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "יש להתקין את היישומון לטלפון הנייד שלך כדי לגשת לפתקים שלך מכל מקום.",
     "Details" : "פרטים",
     "Delete note" : "מחיקת פתק",
     "Remove from favorites" : "הסרה מהמועדפים",
@@ -55,6 +42,13 @@ OC.L10N.register(
     "Full screen" : "מסך מלא",
     "Save failed. Click to retry." : "השמירה נכשלה. יש ללחוץ כדי לנסות שוב.",
     "Error from Nextcloud server: {msg}" : "שגיאה משרת ה־Nextcloud:‏ {msg}",
+    "Loading …" : "בטעינה",
+    "Today" : "היום",
+    "Yesterday" : "אתמול",
+    "This week" : "השבוע",
+    "Last week" : "שבוע שעבר",
+    "This month" : "החודש",
+    "Last month" : "חודש שעבר",
     "Category" : "קטגוריה",
     "Uncategorized" : "ללא קטגוריה",
     "Set category" : "הגדרת קטגוריה",
@@ -65,6 +59,8 @@ OC.L10N.register(
     "Subcategory" : "תת־קטגוריה",
     "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
     "_%n character_::_%n characters_" : ["תו אחד","%n תווים","%n תווים","%n תווים"],
+    "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "ניתן ליצור תת־קטגוריות על ידי שימוש ב־„/” כמפריד בין קטגוריית ההורה ותת־הקטגוריה, למשל: „‎{parent}/{sub}‎”.",
     "Note not found." : "הפתק לא נמצא.",
     "Note is locked." : "הפתק נעול.",
