@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "Pogreška",
     "New note" : "Nova bilješka",
     "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
-    "Help" : "Pomoć",
     "Please see Nextcloud server log for details." : "Pojedinosti potražite u zapisniku Nextcloudovog poslužitelja.",
     "Deleted {title}" : "Izbrisano {title}",
     "Undo Delete" : "Vrati izbrisano",
@@ -16,30 +15,18 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Oporavljena {number} bilješka","Oporavljene {number} bilješke","Oporavljeno {number} bilješki"],
     "Write down your thoughts without any distractions." : "Zapišite svoje misli bez ometanja.",
     "Organize your notes in categories." : "Organizirajte svoje bilješke po kategorijama.",
-    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
-    "Result" : "Rezultat",
-    "Shortcuts" : "Prečaci",
-    "Action" : "Radnja",
-    "Insert image" : "Umetni sliku",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
     "Folder to store your notes" : "Mapa za spremanje bilješki",
     "File extension for new notes" : "Ekstenzija datoteke za nove bilješke",
     "Display mode for notes" : "Način prikaza bilješki",
+    "Shortcuts" : "Prečaci",
+    "Action" : "Radnja",
     "Open in edit mode" : "Otvori u načinu uređivanja",
     "Open in preview mode" : "Otvori u načinu pregleda",
-    "No notes yet" : "Još nema bilješki",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalirajte aplikaciju na svoj mobilni telefon kako biste s bilo kojeg mjesta mogli pristupiti svojim bilješkama.",
+    "Insert image" : "Umetni sliku",
     "All notes" : "Sve bilješke",
     "Categories" : "Kategorije",
-    "Loading …" : "Učitavanje…",
-    "Today" : "Danas",
-    "Yesterday" : "Jučer",
-    "This week" : "Ovaj tjedan",
-    "Last week" : "Prošli tjedan",
-    "This month" : "Ovaj mjesec",
-    "Last month" : "Prošli mjesec",
-    "Rename" : "Preimenuj",
-    "Note's title" : "Naslov bilješke",
+    "No notes yet" : "Još nema bilješki",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalirajte aplikaciju na svoj mobilni telefon kako biste s bilo kojeg mjesta mogli pristupiti svojim bilješkama.",
     "Details" : "Pojedinosti",
     "Delete note" : "Izbriši bilješku",
     "Remove from favorites" : "Ukloni iz favorita",
@@ -59,6 +46,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Spremanje nije uspjelo. Kliknite za ponovni pokušaj.",
     "Update conflict. Click for resolving manually." : "Nepodudaranje ažuriranja. Kliknite za ručno otklanjanje nepodudaranja.",
     "Error from Nextcloud server: {msg}" : "Pogreška Nextcloudovog poslužitelja: {msg}",
+    "Loading …" : "Učitavanje…",
+    "Today" : "Danas",
+    "Yesterday" : "Jučer",
+    "This week" : "Ovaj tjedan",
+    "Last week" : "Prošli tjedan",
+    "This month" : "Ovaj mjesec",
+    "Last month" : "Prošli mjesec",
     "Category" : "Kategorija",
     "Uncategorized" : "Nekategorizirani",
     "Set category" : "Postavi kategoriju",
@@ -69,6 +63,8 @@ OC.L10N.register(
     "Subcategory" : "Potkategorija",
     "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"],
     "_%n character_::_%n characters_" : ["%n znak","%n znaka","%n znakova"],
+    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Možete kreirati potkategorije korištenjem \"/\" kao odjeljivača između nadređene kategorije i potkategorije, npr. “{parent}/{sub}”.",
     "Note not found." : "Bilješka nije pronađena.",
     "Note is locked." : "Bilješka je zaključana.",
