@@ -4,18 +4,16 @@ OC.L10N.register(
     "Notes" : "Նոթեր",
     "Error" : "Սխալ",
     "New note" : "Նոր նոթ",
-    "Help" : "Օգնություն",
     "No notes yet" : "առայժմ գրառում չկա",
-    "Today" : "այսօր",
-    "Yesterday" : "երեկ",
-    "This week" : "այս շաբաթ",
-    "This month" : "այս ամիս",
-    "Rename" : "Վերանվանել",
     "Details" : "Մանրամասներ",
     "Delete note" : "Ջնջել նոթը",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "մշակել",
+    "Today" : "այսօր",
+    "Yesterday" : "երեկ",
+    "This week" : "այս շաբաթ",
+    "This month" : "այս ամիս",
     "_%n word_::_%n words_" : ["%n բառ","%n բառ"]
 },
 "nplurals=2; plural=(n != 1);");
