@@ -4,21 +4,19 @@ OC.L10N.register(
     "Notes" : "Catatan",
     "Error" : "Kesalahan",
     "New note" : "Catatan baru",
-    "Help" : "Bantuan",
-    "No notes yet" : "Belum ada catatan",
     "All notes" : "Semua catatan",
     "Categories" : "Kategori",
-    "Today" : "Hari ini",
-    "Yesterday" : "Kemarin",
-    "This week" : "Pekan ini",
-    "This month" : "Bulan ini",
-    "Rename" : "Ubah nama",
+    "No notes yet" : "Belum ada catatan",
     "Details" : "Detil",
     "Delete note" : "Hapus catatan",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
     "Edit" : "Sunting",
     "Preview" : "Pratinjau",
+    "Today" : "Hari ini",
+    "Yesterday" : "Kemarin",
+    "This week" : "Pekan ini",
+    "This month" : "Bulan ini",
     "Category" : "Kategori",
     "_%n word_::_%n words_" : ["%n kata"],
     "Tasks" : "Tugas",
