@@ -5,25 +5,17 @@ OC.L10N.register(
     "Error" : "Villa",
     "New note" : "Nýr minnispunktur",
     "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
-    "Help" : "Hjálp",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
-    "Result" : "Niðurstöður",
-    "Action" : "Aðgerð",
-    "Insert image" : "Setja inn mynd",
     "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
     "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
     "Display mode for notes" : "Birtingarhamur minnispunkta",
+    "Action" : "Aðgerð",
     "Open in edit mode" : "Opna í breytingaham",
     "Open in preview mode" : "Opna í forskoðunarham",
-    "No notes yet" : "Engir minnispunktar ennþá",
+    "Insert image" : "Setja inn mynd",
     "All notes" : "Allir minnispunktar",
     "Categories" : "Flokkar",
-    "Loading …" : "Hleð inn …",
-    "Today" : "Í dag",
-    "Yesterday" : "Yesterday",
-    "This week" : "Í þessari viku",
-    "This month" : "Í þessum mánuði",
-    "Rename" : "Endurnefna",
+    "No notes yet" : "Engir minnispunktar ennþá",
     "Details" : "Details",
     "Delete note" : "Eyða minnispunkti",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
@@ -31,6 +23,11 @@ OC.L10N.register(
     "Use current version" : "Nota fyrirliggjandi útgáfu",
     "Edit" : "Breyta",
     "Preview" : "Forskoðun",
+    "Loading …" : "Hleð inn …",
+    "Today" : "Í dag",
+    "Yesterday" : "Yesterday",
+    "This week" : "Í þessari viku",
+    "This month" : "Í þessum mánuði",
     "Category" : "Flokkur",
     "Uncategorized" : "Óflokkað",
     "Saving failed!" : "Vistun mistókst!",
