@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "Errore",
     "New note" : "Nuova nota",
     "Distraction-free notes and writing" : "Note senza distrazioni e scrittura",
-    "Help" : "Assistenza",
     "Please see Nextcloud server log for details." : "Vedi i log del server Nextcloud per i dettagli.",
     "Deleted {title}" : "Eliminato {title}",
     "Undo Delete" : "Annulla eliminazione",
@@ -16,19 +15,18 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Ripristinata {number} nota","Ripristinate {number} note","Ripristinate {number} note"],
     "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
     "Organize your notes in categories." : "Organizza le tue note in categorie.",
-    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
-    "Result" : "Risultato",
-    "Shortcuts" : "Scorciatoie",
-    "Action" : "Azione",
-    "Insert image" : "Inserisci immagine",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
     "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
     "Root directory" : "Cartella principale",
     "File extension for new notes" : "Estensione dei file per le nuove note",
     "Display mode for notes" : "Modalità di visualizzazione delle note",
+    "Shortcuts" : "Scorciatoie",
+    "Action" : "Azione",
     "User defined" : "Utente definito",
     "Open in edit mode" : "Apri in modalità modifica",
     "Open in preview mode" : "Apri in modalità anteprima",
+    "Insert image" : "Inserisci immagine",
+    "All notes" : "Tutte le note",
+    "Categories" : "Categorie",
     "No notes yet" : "Ancora nessuna nota",
     "Upload image" : "Carica immagine",
     "Select an image" : "Seleziona un'immagine",
@@ -36,17 +34,6 @@ OC.L10N.register(
     "Wrong image" : "Immagine errata",
     "The file was not uploaded. Check your server logs." : "Il file non è stato caricato. Controlla i log del tuo server.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
-    "All notes" : "Tutte le note",
-    "Categories" : "Categorie",
-    "Loading …" : "Caricamento...",
-    "Today" : "Oggi",
-    "Yesterday" : "Ieri",
-    "This week" : "Questa settimana",
-    "Last week" : "Settimana scorsa",
-    "This month" : "Questo mese",
-    "Last month" : "Mese scorso",
-    "Rename" : "Rinomina",
-    "Note's title" : "Titolo della nota",
     "Details" : "Dettagli",
     "Delete note" : "Elimina nota",
     "Remove from favorites" : "Rimuovi dai preferiti",
@@ -66,6 +53,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
     "Update conflict. Click for resolving manually." : "Conflitto di aggiornamento. Fai clic per risolvere manualmente.",
     "Error from Nextcloud server: {msg}" : "Errore dal server di Nextcloud: {msg}",
+    "Loading …" : "Caricamento...",
+    "Today" : "Oggi",
+    "Yesterday" : "Ieri",
+    "This week" : "Questa settimana",
+    "Last week" : "Settimana scorsa",
+    "This month" : "Questo mese",
+    "Last month" : "Mese scorso",
     "Category" : "Categoria",
     "Uncategorized" : "Senza categoria",
     "Set category" : "Imposta categoria",
@@ -76,6 +70,8 @@ OC.L10N.register(
     "Subcategory" : "Sottocategoria",
     "_%n word_::_%n words_" : ["%n parola","%n parole","%n parole"],
     "_%n character_::_%n characters_" : ["%n carattere","%n caratteri","%n caratteri"],
+    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Puoi creare sottocategorie utilizzando \"/\" come delimitatore tra la categoria superiore e la sottocategoria, ad. es \"{parent}/{sub}\".",
     "Note not found." : "Nota non trovata.",
     "Note is locked." : "La nota è bloccata.",
