@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "エラー",
     "New note" : "新しいノート",
     "Distraction-free notes and writing" : "集中モードのノートと執筆",
-    "Help" : "ヘルプ",
     "Please see Nextcloud server log for details." : "詳細はNextcloudサーバーログを確認してください。",
     "Deleted {title}" : "{title}を削除しました",
     "Undo Delete" : "削除取り消し",
@@ -16,18 +15,17 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["{number}のノートを復元しました"],
     "Write down your thoughts without any distractions." : "気を散らすことなくあなたの考えを書き留めてください。",
     "Organize your notes in categories." : "ノートをカテゴリ別に整理します",
-    "Use Markdown markups to style your text." : "マークダウン・マークアップを使用してテキストを整えます",
-    "Result" : "結果",
-    "Action" : "アクション",
-    "Insert image" : "画像の挿入",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "アプリのナビゲーションで「{newnote}」をクリックしてノートを書き始めます",
     "Folder to store your notes" : "ノートを保存するフォルダー",
     "Root directory" : "ルートディレクトリ",
     "File extension for new notes" : "新しいノートのファイル拡張子",
     "Display mode for notes" : "ノートの表示モード",
+    "Action" : "アクション",
     "User defined" : "ユーザー定義",
     "Open in edit mode" : "編集モードで開く",
     "Open in preview mode" : "プレビューモードで開く",
+    "Insert image" : "画像の挿入",
+    "All notes" : "すべてのノート",
+    "Categories" : "カテゴリ",
     "No notes yet" : "まだノートはありません",
     "Upload image" : "画像をアップロード",
     "Select an image" : "画像を選択",
@@ -35,17 +33,6 @@ OC.L10N.register(
     "Wrong image" : "使用できない画像",
     "The file was not uploaded. Check your server logs." : "ファイルがアップロードされていません。サーバーログをご確認ください。",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "どこからでもあなたのノートにアクセスするため、あなたの携帯電話にアプリをインストールしてください。",
-    "All notes" : "すべてのノート",
-    "Categories" : "カテゴリ",
-    "Loading …" : "読み込み中...",
-    "Today" : "今日",
-    "Yesterday" : "昨日",
-    "This week" : "今週",
-    "Last week" : "先週",
-    "This month" : "今月",
-    "Last month" : "先月",
-    "Rename" : "名前変更",
-    "Note's title" : "ノートタイトル",
     "Details" : "詳細",
     "Delete note" : "ノートを削除",
     "Remove from favorites" : "お気に入りから削除",
@@ -65,6 +52,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "保存失敗, クリックで再試行",
     "Update conflict. Click for resolving manually." : "更新が衝突しました。手動で解決するためにクリック。",
     "Error from Nextcloud server: {msg}" : "Nextcloudサーバーエラー: {msg}",
+    "Loading …" : "読み込み中...",
+    "Today" : "今日",
+    "Yesterday" : "昨日",
+    "This week" : "今週",
+    "Last week" : "先週",
+    "This month" : "今月",
+    "Last month" : "先月",
     "Category" : "カテゴリ",
     "Uncategorized" : "未分類",
     "Set category" : "カテゴリを設定",
@@ -75,6 +69,8 @@ OC.L10N.register(
     "Subcategory" : "サブカテゴリ",
     "_%n word_::_%n words_" : ["%n 単語"],
     "_%n character_::_%n characters_" : ["%n文字"],
+    "Use Markdown markups to style your text." : "マークダウン・マークアップを使用してテキストを整えます",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "アプリのナビゲーションで「{newnote}」をクリックしてノートを書き始めます",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "親カテゴリとサブカテゴリの間の区切り文字として「/」を使用して、サブカテゴリを作成できます。 “ {parent} / {sub}”",
     "Note not found." : "ノートが見つかりません。",
     "Note is locked." : "ノートがロックされています。",
