@@ -4,25 +4,22 @@ OC.L10N.register(
     "Notes" : "ჩანაწერები",
     "Error" : "შეცდომა",
     "New note" : "ახალი ჩანაწერი",
-    "Help" : "დახმარება",
     "There are unsaved notes. Leaving the page will discard all changes!" : "არსებობს შეუნახავი ჩანაწერები. გვერდის დატოვება ყველა ცვლილებას უარყოფს!",
-    "Result" : "შედეგი",
     "Action" : "ქმედება",
     "Open in edit mode" : "გახსენით ცვლილების რეჟიმში",
     "Open in preview mode" : "გახსენით წინასწარი ჩვენების რეჟიმში",
-    "No notes yet" : "ჯერ ჩანაწერები არაა",
     "Categories" : "კატეგორიები",
-    "Today" : "დღეს",
-    "Yesterday" : "გუშინ",
-    "This week" : "ამ კვირაში",
-    "This month" : "ამ თვეში",
-    "Rename" : "სახელის შეცვლა",
+    "No notes yet" : "ჯერ ჩანაწერები არაა",
     "Details" : "დეტალები",
     "Delete note" : "ჩანაწერის გაუქმება",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
     "Edit" : "ცვლილება",
     "Preview" : "წინასწარი ჩვენება",
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "This week" : "ამ კვირაში",
+    "This month" : "ამ თვეში",
     "Category" : "კატეგორია",
     "Uncategorized" : "არაკატეგორიზირებული",
     "Saving failed!" : "შენახვა ვერ მოხერხდა!",
