@@ -5,7 +5,8 @@ OC.L10N.register(
     "Reading notes from filesystem has failed." : "파일시스템에서 메모를 불러오기 실패",
     "Error" : "오류",
     "New note" : "새 메모",
-    "Help" : "도움말",
+    "Distraction-free notes and writing" : "방해 없는 무료 메모 작성 앱",
+    "Notes settings" : "메모 설정",
     "Please see Nextcloud server log for details." : "Nextcloud 서버 로그에서 자세한 사항을 확인하십시오.",
     "Deleted {title}" : "{title} 삭제함",
     "Undo Delete" : "삭제 취소",
@@ -13,27 +14,17 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "저장하지 않은 메모가 있습니다. 이 페이지를 벗어나면 변경 사항이 손실됩니다!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["{number}개의 메모를 삭제함"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["{number}개의 메모를 복구함"],
-    "Result" : "결과",
-    "Shortcuts" : "단축키",
-    "Action" : "동작",
-    "Notes settings" : "메모 설정",
     "Folder to store your notes" : "메모를 저장할 폴더",
     "Root directory" : "루트 디렉터리",
     "File extension for new notes" : "새 메모에 대한 파일 확장자",
     "Display mode for notes" : "노트 표시 모드",
+    "Shortcuts" : "단축키",
+    "Action" : "동작",
     "Open in edit mode" : "편집 모드로 열기",
     "Open in preview mode" : "미리 보기 모드로 열기",
-    "No notes yet" : "아직 메모 없음",
     "All notes" : "모든 메모",
     "Categories" : "분류",
-    "Loading …" : "불러오는 중 …",
-    "Today" : "오늘",
-    "Yesterday" : "어제",
-    "This week" : "이번 주",
-    "Last week" : "저번 주",
-    "This month" : "이번 달",
-    "Last month" : "저번 달",
-    "Rename" : "이름 바꾸기",
+    "No notes yet" : "아직 메모 없음",
     "Details" : "세부사항",
     "Delete note" : "메모 삭제",
     "Remove from favorites" : "즐겨찾기에서 제거",
@@ -41,6 +32,13 @@ OC.L10N.register(
     "Use current version" : "최근 버전을 사용하십시오.",
     "Edit" : "편집",
     "Preview" : "미리 보기",
+    "Loading …" : "불러오는 중 …",
+    "Today" : "오늘",
+    "Yesterday" : "어제",
+    "This week" : "이번 주",
+    "Last week" : "저번 주",
+    "This month" : "이번 달",
+    "Last month" : "저번 달",
     "Category" : "분류",
     "Uncategorized" : "분류되지 않음",
     "Saving failed!" : "저장할 수 없습니다!",
