@@ -2,15 +2,13 @@ OC.L10N.register(
     "notes",
     {
     "Error" : "ຜິດພາດ",
-    "Help" : "ການຊ່ວຍເຫຼືອ",
-    "Loading …" : "ກຳລັງໂຫຼດ",
-    "Today" : "ມື້ນີ້",
-    "Yesterday" : "ມື້ວານນີ້",
-    "This week" : "ທິດນີ້",
-    "Rename" : "ປ່ຽນຊື່",
     "Details" : "ລາຍລະອຽດ",
     "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
     "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
-    "Edit" : "ແກ້ໄຂ"
+    "Edit" : "ແກ້ໄຂ",
+    "Loading …" : "ກຳລັງໂຫຼດ",
+    "Today" : "ມື້ນີ້",
+    "Yesterday" : "ມື້ວານນີ້",
+    "This week" : "ທິດນີ້"
 },
 "nplurals=1; plural=0;");
