@@ -4,22 +4,20 @@ OC.L10N.register(
     "Notes" : "Piezīmes",
     "Error" : "Kļūda",
     "New note" : "Jauna piezīme",
-    "Help" : "Palīdzība",
     "Action" : "Darbība",
-    "No notes yet" : "Nav nevienas piezīmes",
     "All notes" : "Visas piezīmes",
     "Categories" : "Kategorijas",
-    "Today" : "Šodien",
-    "Yesterday" : "Vakar",
-    "This week" : "Šonedēļ",
-    "This month" : "Šis mēnesis",
-    "Rename" : "Pārsaukt",
+    "No notes yet" : "Nav nevienas piezīmes",
     "Details" : "Detaļas",
     "Delete note" : "Dzēst piezīmi",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
     "Edit" : "Rediģēt",
     "Preview" : "Priekšskatīt",
+    "Today" : "Šodien",
+    "Yesterday" : "Vakar",
+    "This week" : "Šonedēļ",
+    "This month" : "Šis mēnesis",
     "Category" : "Kategorija",
     "Uncategorized" : "Bez kategorijas",
     "_%n word_::_%n words_" : ["%n words","%n vārdi","%n vārdi"],
