@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "Грешка",
     "New note" : "Нова белешка",
     "Distraction-free notes and writing" : "Пушување на белешки без одвлекување на вниманието",
-    "Help" : "Помош",
     "Please see Nextcloud server log for details." : "За повеќе детали проверете ги записите во серверот.",
     "Deleted {title}" : "Избришана {title}",
     "Undo Delete" : "Врати бришење",
@@ -16,23 +15,12 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Вратена {number} белешка","Вратени {number} белешки"],
     "Write down your thoughts without any distractions." : "Запишете ги мислите без одвлекување на вниманието.",
     "Organize your notes in categories." : "Организирајте ги вашите белешки во категории.",
-    "Use Markdown markups to style your text." : "Користете ознаки за означување за стилизирање на вашиот текст.",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишувате белешка со притискање на “{newnote}” во навигацијата на апликацијата.",
     "Folder to store your notes" : "Папка за зачувување на вашите белешки",
     "File extension for new notes" : "Наставка на дадотека за нови белешки",
-    "No notes yet" : "Сеуште нема забелешки",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте ја апликацијата за мобилен телефон за да можете да пристапувате до вашите белешки од секаде.",
     "All notes" : "Сите белешки",
     "Categories" : "Категории",
-    "Loading …" : "Се вчитува…",
-    "Today" : "Денес",
-    "Yesterday" : "Вчера",
-    "This week" : "Оваа недела",
-    "Last week" : "Минатата недела",
-    "This month" : "Овој месец",
-    "Last month" : "Минатиот месец",
-    "Rename" : "Преименувај",
-    "Note's title" : "Наслов на белешката",
+    "No notes yet" : "Сеуште нема забелешки",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте ја апликацијата за мобилен телефон за да можете да пристапувате до вашите белешки од секаде.",
     "Details" : "Детали",
     "Delete note" : "Избриши белешка",
     "Remove from favorites" : "Отстрани од фаворити",
@@ -48,6 +36,13 @@ OC.L10N.register(
     "Full screen" : "Цел екран",
     "Save failed. Click to retry." : "Неуспешно зачувување. Крикни за повторен обид.",
     "Error from Nextcloud server: {msg}" : "Грешка од серверот: {msg}",
+    "Loading …" : "Се вчитува…",
+    "Today" : "Денес",
+    "Yesterday" : "Вчера",
+    "This week" : "Оваа недела",
+    "Last week" : "Минатата недела",
+    "This month" : "Овој месец",
+    "Last month" : "Минатиот месец",
     "Category" : "Категорија",
     "Uncategorized" : "Некатегоризирани",
     "Set category" : "Постави категорија",
@@ -58,6 +53,8 @@ OC.L10N.register(
     "Subcategory" : "Подкатегорија",
     "_%n word_::_%n words_" : ["%n збор","%n зборови"],
     "_%n character_::_%n characters_" : ["%n карактер","%n карактери"],
+    "Use Markdown markups to style your text." : "Користете ознаки за означување за стилизирање на вашиот текст.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишувате белешка со притискање на “{newnote}” во навигацијата на апликацијата.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да креирате поткатегории со употреба на „/“ како разграничувач помеѓу главната категорија и поткатегоријата, на пр. “{parent}/{sub}”.",
     "Note not found." : "Белешката не е пронајдена.",
     "Note is locked." : "Белешката е заклучена.",
