@@ -4,22 +4,20 @@ OC.L10N.register(
     "Notes" : "Тэмдэглэл",
     "Error" : "Алдаа",
     "New note" : "Шинэ тэмдэглэл",
-    "Help" : "Туслах",
-    "No notes yet" : "шинэ тэмдэглэл алга",
     "All notes" : "Бүх тэмдэг",
     "Categories" : "төрөл",
-    "Loading …" : "Уншиж байна...",
-    "Today" : "өнөөдөр",
-    "Yesterday" : "өчигдөр",
-    "This week" : "7 хоног",
-    "This month" : "1 сар",
-    "Rename" : "Нэрлэнэ үү",
+    "No notes yet" : "шинэ тэмдэглэл алга",
     "Details" : "Дэлгэрэнгүй",
     "Delete note" : "Тэмдэглэл устгах",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "засварлах",
     "Preview" : "шалгах",
+    "Loading …" : "Уншиж байна...",
+    "Today" : "өнөөдөр",
+    "Yesterday" : "өчигдөр",
+    "This week" : "7 хоног",
+    "This month" : "1 сар",
     "Category" : "Ангилал"
 },
 "nplurals=2; plural=(n != 1);");
