@@ -4,13 +4,11 @@ OC.L10N.register(
     "Notes" : "Nota",
     "Error" : "Ralat",
     "New note" : "Note baharu",
-    "Help" : "Bantuan",
-    "Today" : "Hari ini",
-    "Yesterday" : "Semalam",
-    "Rename" : "Namakan",
     "Delete note" : "Hapus nota",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Edit" : "Sunting"
+    "Edit" : "Sunting",
+    "Today" : "Hari ini",
+    "Yesterday" : "Semalam"
 },
 "nplurals=1; plural=0;");
