@@ -4,26 +4,16 @@ OC.L10N.register(
     "Notes" : "Notater",
     "Error" : "Feil",
     "New note" : "Nytt notat",
-    "Help" : "Hjelp",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finnes ulagrede notater. Å forlate siden vil forkaste alle endringer!",
-    "Result" : "Resultat",
+    "Display mode for notes" : "Visningsmodus for notater",
     "Shortcuts" : "Snarveier",
     "Action" : "Handling",
-    "Insert image" : "Sett inn bilde",
-    "Display mode for notes" : "Visningsmodus for notater",
     "Open in edit mode" : "Åpne i redigeringsmodus",
     "Open in preview mode" : "Åpne i forhåndsvisningsmodus",
-    "No notes yet" : "Ingen notater enda",
+    "Insert image" : "Sett inn bilde",
     "All notes" : "Alle notater",
     "Categories" : "Kategorier",
-    "Loading …" : "Laster...",
-    "Today" : "I dag",
-    "Yesterday" : "I går",
-    "This week" : "Denne uken",
-    "Last week" : "Forrige uke",
-    "This month" : "Denne måneden",
-    "Last month" : "Forrige måned",
-    "Rename" : "Endre navn",
+    "No notes yet" : "Ingen notater enda",
     "Details" : "Detaljer",
     "Delete note" : "Slett notat",
     "Remove from favorites" : "Fjern fra favoritter",
@@ -31,6 +21,13 @@ OC.L10N.register(
     "Use current version" : "Bruk siste versjon",
     "Edit" : "Rediger",
     "Preview" : "Forhåndsvis",
+    "Loading …" : "Laster...",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
+    "This week" : "Denne uken",
+    "Last week" : "Forrige uke",
+    "This month" : "Denne måneden",
+    "Last month" : "Forrige måned",
     "Category" : "Kategori",
     "Uncategorized" : "Ukategorisert",
     "Saving failed!" : "Lagring mislyktes!",
