@@ -6,7 +6,7 @@ OC.L10N.register(
     "Error" : "Fout",
     "New note" : "Nieuwe notitie",
     "Distraction-free notes and writing" : "Afleidingsvrije notities en schrijven",
-    "Help" : "Help",
+    "Notes settings" : "Notities instellingen",
     "Please see Nextcloud server log for details." : "Bekijk het Nextcloud-serverlogboek voor details.",
     "Deleted {title}" : "{title} verwijderd",
     "Undo Delete" : "Verwijderen ongedaan maken",
@@ -16,11 +16,16 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Herstelde {number} notitie","{number} notities hersteld"],
     "Write down your thoughts without any distractions." : "Schrijf je gedachten op zonder afleiding.",
     "Organize your notes in categories." : "Organiseer je notities in categorieën. ",
-    "Use Markdown markups to style your text." : "Gebruik Markdown markeringen om je tekst op te maken.",
-    "Result" : "Resultaat",
+    "Folder to store your notes" : "Map om je notities in op te slaan",
+    "Root directory" : "Root directory",
+    "File extension for new notes" : "Bestandsextensie voor nieuwe notities",
+    "Display mode for notes" : "Weergavemodus voor notities",
     "Shortcuts" : "Snelkoppelingen",
     "Action" : "Actie",
     "Mobile apps" : "Mobiele apps",
+    "User defined" : "Door gebruiker ingesteld",
+    "Open in edit mode" : "Open in bewerkingsmodus",
+    "Open in preview mode" : "Open in voorbeeldmodus",
     "CTRL" : "CTRL",
     "Make the selection bold" : "Zet de selectie in vet",
     "Make the selection italic" : "Zet de selectie in cursief",
@@ -29,21 +34,8 @@ OC.L10N.register(
     "The selection will be turned into monospace" : "De selectie wordt omgezet naar vaste letterbreedte",
     "SHIFT" : "SHIFT",
     "Insert image" : "Invoegen afbeelding",
-    "bold" : "vet",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Start een nieuwe notitie door op \"{newnote}\" te klikken in de app navigatie.",
-    "italic" : "cursief",
-    "strikethrough" : "doorgehaald",
-    "link" : "link",
-    "image" : "afbeelding",
-    "quote" : "quote",
-    "Notes settings" : "Notities instellingen",
-    "Folder to store your notes" : "Map om je notities in op te slaan",
-    "Root directory" : "Root directory",
-    "File extension for new notes" : "Bestandsextensie voor nieuwe notities",
-    "Display mode for notes" : "Weergavemodus voor notities",
-    "User defined" : "Door gebruiker ingesteld",
-    "Open in edit mode" : "Open in bewerkingsmodus",
-    "Open in preview mode" : "Open in voorbeeldmodus",
+    "All notes" : "Alle notities",
+    "Categories" : "Categorieën",
     "No notes yet" : "Nog geen notities aanwezig",
     "Upload image" : "Upload afbeelding",
     "Select an image" : "Selecteer een afbeelding",
@@ -51,17 +43,6 @@ OC.L10N.register(
     "Wrong image" : "Verkeerde afbeelding",
     "The file was not uploaded. Check your server logs." : "Het bestand is niet geupload. Bekijk uw Server-logboeken",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installeer de app op je mobiel om overal toegang tot je notities te krijgen.",
-    "All notes" : "Alle notities",
-    "Categories" : "Categorieën",
-    "Loading …" : "Laden ...",
-    "Today" : "Vandaag",
-    "Yesterday" : "Gisteren",
-    "This week" : "Deze week",
-    "Last week" : "Vorige week",
-    "This month" : "Deze maand",
-    "Last month" : "Vorige maand",
-    "Rename" : "Hernoemen",
-    "Note's title" : "Notitietitel",
     "Details" : "Details",
     "Delete note" : "Verwijder notitie",
     "Remove from favorites" : "Verwijderen uit favorieten",
@@ -81,6 +62,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Opslaan mislukt. Klik om opnieuw te proberen.",
     "Update conflict. Click for resolving manually." : "Bijwerkconflict. Klik om het handmatig op te lossen.",
     "Error from Nextcloud server: {msg}" : "Fout van Nextcloud-server: {msg}",
+    "Loading …" : "Laden ...",
+    "Today" : "Vandaag",
+    "Yesterday" : "Gisteren",
+    "This week" : "Deze week",
+    "Last week" : "Vorige week",
+    "This month" : "Deze maand",
+    "Last month" : "Vorige maand",
     "Category" : "Categorie",
     "Uncategorized" : "Niet gecategoriseerd ",
     "Set category" : "Bepaal categorie",
@@ -91,6 +79,8 @@ OC.L10N.register(
     "Subcategory" : "Subcategorie",
     "_%n word_::_%n words_" : ["%n woord","%n woorden"],
     "_%n character_::_%n characters_" : ["%n teken","%n tekens"],
+    "Use Markdown markups to style your text." : "Gebruik Markdown markeringen om je tekst op te maken.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Start een nieuwe notitie door op \"{newnote}\" te klikken in de app navigatie.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Je kunt sub-categorieën maken door “/” te gebruiken als scheidingsteken tussen hoofdcategorie en sub-categorie, bijv. “{parent}/{sub}”.",
     "Note not found." : "Notitie niet gevonden.",
     "Note is locked." : "Notitie is geblokkeerd.",
