@@ -4,20 +4,11 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Erro",
     "New note" : "Nova nota",
-    "Help" : "Ajuda",
     "Open in edit mode" : "Abrir no modo de edição",
     "Open in preview mode" : "Abrir no modo de visualização",
-    "No notes yet" : "Sem notas ainda",
     "All notes" : "Todas as notas",
     "Categories" : "Categorias",
-    "Loading …" : "A carregar...",
-    "Today" : "Hoje",
-    "Yesterday" : "Ontem",
-    "This week" : "Esta semana",
-    "Last week" : "Ultima semana",
-    "This month" : "Este mês",
-    "Last month" : "Ultimo mês",
-    "Rename" : "Renomear",
+    "No notes yet" : "Sem notas ainda",
     "Details" : "Detalhes",
     "Delete note" : "Apagar nota",
     "Remove from favorites" : "Remover de favoritos",
@@ -25,6 +16,13 @@ OC.L10N.register(
     "Use current version" : "Usar esta versão",
     "Edit" : "Editar",
     "Preview" : "Pré-visualização",
+    "Loading …" : "A carregar...",
+    "Today" : "Hoje",
+    "Yesterday" : "Ontem",
+    "This week" : "Esta semana",
+    "Last week" : "Ultima semana",
+    "This month" : "Este mês",
+    "Last month" : "Ultimo mês",
     "Category" : "Categoria",
     "_%n word_::_%n words_" : ["%n palavra","%n palavras","%n palavras"],
     "Tasks" : "Tarefas"
