@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "Eroare",
     "New note" : "Notă nouă",
     "Distraction-free notes and writing" : "Scrie notiţe fără a fi distras",
-    "Help" : "Ajutor",
     "Please see Nextcloud server log for details." : "Vă rugăm să verificaţi fişierele log de pe serverul Nextcloud pentru mai multe detalii.",
     "Deleted {title}" : "{title} a fost şters",
     "Undo Delete" : "Anulează ștergerea",
@@ -16,9 +15,6 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["A fost recuperat {number} notiţă","Au fost recuperate {number} notiţe","Au fost recuperate {number} de notiţe"],
     "Write down your thoughts without any distractions." : "Scrie-ţi gândurile fără orice altă distracţie.",
     "Organize your notes in categories." : "Organizează-ţi notoţele pe categorii.",
-    "Use Markdown markups to style your text." : "Foloseşte limbajul Markdown pentru a-ţi stiliza textul.",
-    "Insert image" : "Introdu imagine",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Începe a scrie o notiţă prin a apăsa pe \"{newnote}” în navigaţia aplicaţiei.",
     "Folder to store your notes" : "Dosarul pentru a stoca notiţele tale",
     "Root directory" : "Director rădacină",
     "File extension for new notes" : "Extensia fişierului pentru notiţele noi",
@@ -26,6 +22,9 @@ OC.L10N.register(
     "User defined" : "Definit de utilizator",
     "Open in edit mode" : "Deschide în modul editare",
     "Open in preview mode" : "Deschide în modul de previzualizare ",
+    "Insert image" : "Introdu imagine",
+    "All notes" : "Toate notițele",
+    "Categories" : "Categorii",
     "No notes yet" : "Nu există notițe",
     "Upload image" : "Încarcă imagine",
     "Select an image" : "Selectează o imagine",
@@ -33,17 +32,6 @@ OC.L10N.register(
     "Wrong image" : "Imagine greșită",
     "The file was not uploaded. Check your server logs." : "Imaginea nu a fost încărcată. Verifică fișierele log.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalează alicaţia pentru telefonul tău mobil pentru a-ţi accesa notiţele de oriunde.",
-    "All notes" : "Toate notițele",
-    "Categories" : "Categorii",
-    "Loading …" : "Se încarcă…",
-    "Today" : "Azi",
-    "Yesterday" : "Ieri",
-    "This week" : "Săptămâna asta",
-    "Last week" : "Săptămâna trecută ",
-    "This month" : "Luna asta",
-    "Last month" : "Luna trecută ",
-    "Rename" : "Redenumire",
-    "Note's title" : "Titlul notiţei",
     "Details" : "Detalii",
     "Delete note" : "Şterge nota",
     "Remove from favorites" : "Șterge din favorite",
@@ -63,6 +51,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Salvarea a eşuat. Click pentru a reîncerca.",
     "Update conflict. Click for resolving manually." : "Actualizează conflictul. Click pentru a resolva manual această problemă.",
     "Error from Nextcloud server: {msg}" : "Eroare din partea severului Nextcloud: {msg}",
+    "Loading …" : "Se încarcă…",
+    "Today" : "Azi",
+    "Yesterday" : "Ieri",
+    "This week" : "Săptămâna asta",
+    "Last week" : "Săptămâna trecută ",
+    "This month" : "Luna asta",
+    "Last month" : "Luna trecută ",
     "Category" : "Categorie",
     "Uncategorized" : "Fără categorie ",
     "Set category" : "Setează categoria",
@@ -73,6 +68,8 @@ OC.L10N.register(
     "Subcategory" : "Subcategorie",
     "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"],
     "_%n character_::_%n characters_" : ["%n caracter","%n caractere","%n de caractere"],
+    "Use Markdown markups to style your text." : "Foloseşte limbajul Markdown pentru a-ţi stiliza textul.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Începe a scrie o notiţă prin a apăsa pe \"{newnote}” în navigaţia aplicaţiei.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Poţi creea subcategorii prin folosirea simbolului \"/\" pentru a delimita categoria principală de subcategorie, ex: “{parent}/{sub}”.",
     "Note not found." : "Notița nu a fost găsită.",
     "Note is locked." : "Notiţa este blocată.",
