@@ -2,11 +2,13 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Заметки",
+    "Create new note" : "Создать новую заметку",
+    "More notes" : "Еще заметки",
     "Reading notes from filesystem has failed." : "Чтение заметок из файловой системы не удалось",
     "Error" : "Ошибка",
     "New note" : "Новая заметка",
     "Distraction-free notes and writing" : "Простые заметки и записки",
-    "Help" : "Помощь",
+    "Notes settings" : "Настройки заметок",
     "Please see Nextcloud server log for details." : "Для получения подробной информации, пожалуйста, обратитесь к журналам сервера Nextcloud.",
     "Deleted {title}" : "Заметка {title} удалена",
     "Undo Delete" : "Отменить удаление",
@@ -14,21 +16,29 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Есть несохраненные заметки. Если покинуть страницу, все изменения будут утеряны.",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Удалена [number] заметка","Удалено [number] заметки","Удалено [number] заметок","Удалено [number] заметок"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Восстановлена [number] заметка","Восстановлено [number] заметки","Восстановлено [number] заметок","Восстановлено [number] заметок"],
+    "Basics" : "Основные",
     "Write down your thoughts without any distractions." : "Записывайте свои мысли, ни на что не отвлекаясь.",
     "Organize your notes in categories." : "Поддержка категорий;",
-    "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
-    "Result" : "Результат",
-    "Shortcuts" : "Горячие клавиши",
-    "Action" : "Действие",
-    "Insert image" : "Вставить изображение",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Чтобы создать заметку, нажмите «{newnote}» в панели навигации.",
+    "Notes path" : "Путь к заметкам",
     "Folder to store your notes" : "Папка для хранения заметок",
     "Root directory" : "Корневой каталог",
+    "File extension" : "Расширение файла",
     "File extension for new notes" : "Расширения файлов новых заметок",
+    "Display mode" : "Режим отображения",
     "Display mode for notes" : "Режим отображения для заметок",
+    "Shortcuts" : "Горячие клавиши",
+    "Use shortcuts to quickly navigate this app." : "Используйте горячие клавиши для быстрой навигации по приложению",
+    "Shortcut" : "Горячая клавиша",
+    "Action" : "Действие",
+    "Mobile apps" : "Мобильные приложения",
     "User defined" : "Определено пользователем",
     "Open in edit mode" : "Открыть в режиме редактирования",
     "Open in preview mode" : "Открыть в режиме просмотра",
+    "Insert link" : "Вставить ссылку",
+    "Insert image" : "Вставить изображение",
+    "Switch between editor and viewer" : "Переключиться между редактированием и просмотром",
+    "All notes" : "Все заметки",
+    "Categories" : "Категории",
     "No notes yet" : "Нет ни одной заметки",
     "Upload image" : "Загрузить изображение",
     "Select an image" : "Выберите изображение",
@@ -36,17 +46,6 @@ OC.L10N.register(
     "Wrong image" : "Неверное изображение",
     "The file was not uploaded. Check your server logs." : "Файл не был загружен. Проверьте журналы вашего сервера.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Для доступа к заметкам с телефона установите мобильное приложение.",
-    "All notes" : "Все заметки",
-    "Categories" : "Категории",
-    "Loading …" : "Загрузка ...",
-    "Today" : "Сегодня",
-    "Yesterday" : "Вчера",
-    "This week" : "Эта неделя",
-    "Last week" : "За последнюю неделю",
-    "This month" : "Этот месяц",
-    "Last month" : "За последний месяц",
-    "Rename" : "Переименовать",
-    "Note's title" : "Заголовок заметки",
     "Details" : "Подробнее",
     "Delete note" : "Удалить заметку",
     "Remove from favorites" : "Убрать из избранного",
@@ -66,6 +65,15 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Сохранение не удалось. Нажмите для повтора.",
     "Update conflict. Click for resolving manually." : "Конфликт обновления. Щелкните для разрешения вручную.",
     "Error from Nextcloud server: {msg}" : "Ошибка сервера Nextcloud: {msg}",
+    "Search for notes" : "Поиск заметок",
+    "Loading …" : "Загрузка ...",
+    "Find in all categories" : "Найти во всех категориях",
+    "Today" : "Сегодня",
+    "Yesterday" : "Вчера",
+    "This week" : "Эта неделя",
+    "Last week" : "За последнюю неделю",
+    "This month" : "Этот месяц",
+    "Last month" : "За последний месяц",
     "Category" : "Категория",
     "Uncategorized" : "Без категории",
     "Set category" : "Задать категорию",
@@ -74,8 +82,11 @@ OC.L10N.register(
     "Last modified: {date}" : "Последнее изменение: {date}",
     "Note has unsaved changes" : "Заметка содержит несохраненные изменения",
     "Subcategory" : "Подкатегория",
+    "Click to edit title" : "Нажмите, чтобы изменить заголовок",
     "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
     "_%n character_::_%n characters_" : ["%n символ","%n символа","%n символов","%n символов"],
+    "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Чтобы создать заметку, нажмите «{newnote}» в панели навигации.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Для создания вложенных категорий используйте разделитель «/», например: «{parent}/{sub}».",
     "Note not found." : "Заметка не найдена",
     "Note is locked." : "Заметка заблокирована",
@@ -95,6 +106,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Не удалось установить отметку «избранное» для заметки {id}.",
     "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?",
     "Updating the category for note {id} has failed." : "Не удалось обновить категорию для заметки {id}.",
+    "Sample note" : "Пример заметки",
     "Tasks" : "Задачи",
     "Development Mode" : "Режим разработки",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Вероятно, это приложение было установлено из источника, предназначенного для разработчиков. Настоятельно рекомендуется переустановить его из официального <a href=\"%1$s\">каталога приложений Nextcloud</a>. Инструкции по самостоятельной сборке приложения приведены в  <a href=\"%2$s\">руководстве для разработчиков</a>."
