@@ -6,7 +6,6 @@ OC.L10N.register(
     "Error" : "Errore",
     "New note" : "Nota noa",
     "Distraction-free notes and writing" : "Notas sena disvios e iscritura ",
-    "Help" : "Agiudu",
     "Please see Nextcloud server log for details." : "Càstia is registros de su serbidore Nextcloud pro is detàllios.",
     "Deleted {title}" : "Eliminadu {title}",
     "Undo Delete" : "Annulla eliminatzione",
@@ -16,30 +15,18 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} notas ripristinadas","Notas {number} "],
     "Write down your thoughts without any distractions." : "Piga nota de is pensamentos tuos sena perunu disviu.",
     "Organize your notes in categories." : "Organiza is notas tuas in catègorias.",
-    "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
-    "Result" : "Resurtadu",
-    "Shortcuts" : "Incurtzaduras",
-    "Action" : "Atzione",
-    "Insert image" : "Inserta·nche imàgine",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Cumintza a iscrìere una nota incarchende subra de \"{newnote}\" in s'aplicatzione.",
     "Folder to store your notes" : "Cartella ue memorizare is notas tuas",
     "File extension for new notes" : "Estensione de is archìvios pro is notas noas",
     "Display mode for notes" : "Modalidades de visualizatzione de is notas",
+    "Shortcuts" : "Incurtzaduras",
+    "Action" : "Atzione",
     "Open in edit mode" : "Aberi in modalidade modìfica",
     "Open in preview mode" : "Aberi in modalidade anteprima",
-    "No notes yet" : "Peruna nota ancora",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa s'aplicatzione pro su telefoneddu tuo pro intrare a is notas tuas dae totue.",
+    "Insert image" : "Inserta·nche imàgine",
     "All notes" : "Totu is notas",
     "Categories" : "Categorias",
-    "Loading …" : "Carrigamentu...",
-    "Today" : "Oe",
-    "Yesterday" : "Yesterday",
-    "This week" : "Custa chida",
-    "Last week" : "Sa chida colada",
-    "This month" : "Custu mese",
-    "Last month" : "Su mese passadu",
-    "Rename" : "Torra a numenare",
-    "Note's title" : "Tìtulu de sa nota",
+    "No notes yet" : "Peruna nota ancora",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa s'aplicatzione pro su telefoneddu tuo pro intrare a is notas tuas dae totue.",
     "Details" : "Detàllios",
     "Delete note" : "Elìmina nota",
     "Remove from favorites" : "Boga·nche dae preferidos",
@@ -59,6 +46,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Sarvamentu faddidu. Incarca pro bi torrare a proare.",
     "Update conflict. Click for resolving manually." : "Cunflitu de agiornamentu. Incarca pro isorvere a manu.",
     "Error from Nextcloud server: {msg}" : "Errore dae su serbidore de Nexcloud: {msg}",
+    "Loading …" : "Carrigamentu...",
+    "Today" : "Oe",
+    "Yesterday" : "Yesterday",
+    "This week" : "Custa chida",
+    "Last week" : "Sa chida colada",
+    "This month" : "Custu mese",
+    "Last month" : "Su mese passadu",
     "Category" : "Categoria",
     "Uncategorized" : "Sena categoria",
     "Set category" : "Imposta categoria",
@@ -69,6 +63,8 @@ OC.L10N.register(
     "Subcategory" : "Sutacategoria",
     "_%n word_::_%n words_" : ["%n  paràulas ","%n paràulas"],
     "_%n character_::_%n characters_" : ["%n caràteres","%n caràteres"],
+    "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Cumintza a iscrìere una nota incarchende subra de \"{newnote}\" in s'aplicatzione.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podes creare sutacategorias impreende \"/\" comente tremenàrgiu e sa sutacategoria, pr. es. \"{parent}/{sub}\".",
     "Note not found." : "Nota no agatada.",
     "Note is locked." : "Sa nota est blocada.",
