@@ -4,9 +4,11 @@ OC.L10N.register(
     "Notes" : "සටහන්",
     "Error" : "දෝෂය",
     "New note" : "නව සටහන",
-    "Help" : "උපකාර",
-    "No notes yet" : "තවම සටහන් නැත",
     "All notes" : "සියලුම සටහන්",
+    "No notes yet" : "තවම සටහන් නැත",
+    "Details" : "විස්තර",
+    "Edit" : "සංස්කරණය",
+    "Preview" : "පෙරදසුන",
     "Loading …" : "පූරණය වෙමින් …",
     "Today" : "අද",
     "Yesterday" : "ඊයේ",
@@ -14,10 +16,6 @@ OC.L10N.register(
     "Last week" : "පසුගිය සතිය",
     "This month" : "මෙම මාසය",
     "Last month" : "පසුගිය මාසය",
-    "Rename" : "නැවත නම් කරන්න",
-    "Details" : "විස්තර",
-    "Edit" : "සංස්කරණය",
-    "Preview" : "පෙරදසුන",
     "Category" : "ප්‍රවර්ගය",
     "Tasks" : "කාර්යයන්"
 },
