@@ -6,7 +6,7 @@ OC.L10N.register(
     "Error" : "Chyba",
     "New note" : "Nová poznámka",
     "Distraction-free notes and writing" : "Písanie a poznámky, čo neodpútavajú pozornosť",
-    "Help" : "Pomoc",
+    "Notes settings" : "Nastavenia Poznámok",
     "Please see Nextcloud server log for details." : "Podrobnosti nájdete v protokole servera Nextcloud.",
     "Deleted {title}" : "Zmazané {title}",
     "Undo Delete" : "Zrušiť odstránenie",
@@ -16,23 +16,21 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Bola obnovená {number} poznámka","Boli obnovené {number} poznámky","Boli obnovené {number} poznámky","Bolo obnovených {number} poznámok"],
     "Write down your thoughts without any distractions." : "Zapíšte si nápady bez rušivých elementov.",
     "Organize your notes in categories." : "Organizujte si poznámky do kategórií.",
-    "Use Markdown markups to style your text." : "Použite formát Markdown na formátovanie vášho textu.",
-    "Result" : "Výsledok",
-    "Shortcuts" : "Skratky",
-    "Action" : "Akcia",
-    "CTRL" : "CTRL",
-    "ALT" : "ALT",
-    "SHIFT" : "SHIFT",
-    "Insert image" : "Vložiť obrázok",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Začnite písať poznámku kliknutím na “{newnote}” v menu aplikácie.",
-    "Notes settings" : "Nastavenia Poznámok",
     "Folder to store your notes" : "Priečinok na ukladanie poznámok",
     "Root directory" : "Koreňový adresár",
     "File extension for new notes" : "Prípona súboru pre nové poznámky",
     "Display mode for notes" : "Režim zobrazovania poznámok",
+    "Shortcuts" : "Skratky",
+    "Action" : "Akcia",
     "User defined" : "Definované uživateľom",
     "Open in edit mode" : "Otvoriť v režime úprav",
     "Open in preview mode" : "Otvoriť v režime ukážky",
+    "CTRL" : "CTRL",
+    "ALT" : "ALT",
+    "SHIFT" : "SHIFT",
+    "Insert image" : "Vložiť obrázok",
+    "All notes" : "Všetky poznámky",
+    "Categories" : "Kategórie",
     "No notes yet" : "Zatiaľ nie sú žiadne poznámky",
     "Upload image" : "Nahrať obrázok",
     "Select an image" : "Vybrať obrázok",
@@ -40,17 +38,6 @@ OC.L10N.register(
     "Wrong image" : "Chybný obrázok",
     "The file was not uploaded. Check your server logs." : "Súbor nebol nahraný. Skontrolujte záznam o chybách serveru.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Nainštalujte si aplikáciu pre váš mobil a zoberte si vaše poznámky so sebou kamkoľvek.",
-    "All notes" : "Všetky poznámky",
-    "Categories" : "Kategórie",
-    "Loading …" : "Načítava sa...",
-    "Today" : "Dnes",
-    "Yesterday" : "Včera",
-    "This week" : "Tento týždeň",
-    "Last week" : "Minulý týždeň",
-    "This month" : "Tento mesiac",
-    "Last month" : "Minulý mesiac",
-    "Rename" : "Premenovať",
-    "Note's title" : "Nadpis poznámky",
     "Details" : "Podrobnosti",
     "Delete note" : "Zmazať poznámku",
     "Remove from favorites" : "Odstrániť z obľúbených",
@@ -70,6 +57,13 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Uloženie zlyhalo. Ťuknutím zopakujete.",
     "Update conflict. Click for resolving manually." : "Konflikt pri aktualizácii. Kliknite pre ručné riešenie problému.",
     "Error from Nextcloud server: {msg}" : "Chyba Nextcloud servera: {msg}",
+    "Loading …" : "Načítava sa...",
+    "Today" : "Dnes",
+    "Yesterday" : "Včera",
+    "This week" : "Tento týždeň",
+    "Last week" : "Minulý týždeň",
+    "This month" : "Tento mesiac",
+    "Last month" : "Minulý mesiac",
     "Category" : "Kategória",
     "Uncategorized" : "Nezaradené",
     "Set category" : "Vybrať kategóriu",
@@ -80,6 +74,8 @@ OC.L10N.register(
     "Subcategory" : "Podkategória",
     "_%n word_::_%n words_" : ["%n slovo","%n slov","%n slov","%n slov"],
     "_%n character_::_%n characters_" : ["%n znak","%n znaky","%n znaky","%n znakov"],
+    "Use Markdown markups to style your text." : "Použite formát Markdown na formátovanie vášho textu.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Začnite písať poznámku kliknutím na “{newnote}” v menu aplikácie.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Môžete vytvoriť subkategórie tak, že pridáte oddeľovací znak “/” medzi kategóriu a subkategóriu. Príklad: “{parent}/{sub}”",
     "Note not found." : "Poznámky sa nenašli.",
     "Note is locked." : "Poznámka je zamknutá.",
