@@ -4,24 +4,22 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Error" : "Greška",
     "New note" : "Nova beleška",
-    "Help" : "Pomoć",
     "Display mode for notes" : "Režim prikaza beleški",
     "Open in edit mode" : "Otvori u režimu uređivanja",
     "Open in preview mode" : "Otvori u režimu pregleda",
-    "No notes yet" : "Još nema beleški",
     "All notes" : "Sve beleške",
+    "No notes yet" : "Još nema beleški",
+    "Details" : "Detalji",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
+    "Edit" : "Uredi",
+    "Preview" : "Pregled",
     "Today" : "Today",
     "Yesterday" : "juče",
     "This week" : "Ove sedmice",
     "Last week" : "Prošle nedelje",
     "This month" : "Ovog meseca",
     "Last month" : "Prošlog meseca",
-    "Rename" : "Preimenuj",
-    "Details" : "Detalji",
-    "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites",
-    "Edit" : "Uredi",
-    "Preview" : "Pregled",
     "Category" : "Kategorija",
     "Uncategorized" : "Nekategorizovano"
 },
