@@ -3,14 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "குறிப்புகள்",
     "Error" : "வழு",
-    "Help" : "உதவி",
-    "Today" : "இன்று",
-    "Yesterday" : "நேற்று",
-    "Rename" : "பெயர்மாற்றம்",
     "Details" : "விவரங்கள்",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "தொகுக்க",
+    "Today" : "இன்று",
+    "Yesterday" : "நேற்று",
     "Tasks" : "கடமைகள்"
 },
 "nplurals=2; plural=(n != 1);");
