@@ -4,11 +4,16 @@ OC.L10N.register(
     "Notes" : "โน้ต",
     "Error" : "ข้อผิดพลาด",
     "New note" : "โน้ตใหม่",
-    "Help" : "ช่วยเหลือ",
     "Display mode for notes" : "โหมดแสดงผลสำหรับโน้ต",
     "Open in edit mode" : "เปิดในโหมดแก้ไข",
     "Open in preview mode" : "เปิดในโหมดแสดงตัวอย่าง",
     "All notes" : "โน้ตทั้งหมด",
+    "Details" : "รายละเอียด",
+    "Delete note" : "ลบโน้ต",
+    "Remove from favorites" : "เอาออกจากรายการโปรด",
+    "Add to favorites" : "เพิ่มในรายการโปรด",
+    "Edit" : "แก้ไข",
+    "Preview" : "ตัวอย่าง",
     "Loading …" : "กำลังโหลด …",
     "Today" : "วันนี้",
     "Yesterday" : "เมื่อวาน",
@@ -16,13 +21,6 @@ OC.L10N.register(
     "Last week" : "สัปดาห์ที่แล้ว",
     "This month" : "เดือนนี้",
     "Last month" : "เดือนที่แล้ว",
-    "Rename" : "เปลี่ยนชื่อ",
-    "Details" : "รายละเอียด",
-    "Delete note" : "ลบโน้ต",
-    "Remove from favorites" : "เอาออกจากรายการโปรด",
-    "Add to favorites" : "เพิ่มในรายการโปรด",
-    "Edit" : "แก้ไข",
-    "Preview" : "ตัวอย่าง",
     "Category" : "หมวดหมู่",
     "Uncategorized" : "ไม่ได้จัดหมวดหมู่",
     "_%n word_::_%n words_" : ["%n คำ"],
