@@ -2,11 +2,13 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Нотатки",
+    "Create new note" : "Створити нову нотатку",
+    "More notes" : "Більше нотаток",
     "Reading notes from filesystem has failed." : "Не вдалося прочитати нотатки з файлової системи.",
     "Error" : "Помилка",
     "New note" : "Нова нотатка",
     "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
-    "Help" : "Допомога",
+    "Notes settings" : "Налаштування",
     "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера Nextcloud для отримання додаткової інформації.",
     "Deleted {title}" : "Вилучено {title}",
     "Undo Delete" : "Повернути вилучення",
@@ -17,56 +19,41 @@ OC.L10N.register(
     "Basics" : "Простий",
     "Write down your thoughts without any distractions." : "Записуйте свої думки, не відволікаючись.",
     "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
-    "Markdown" : "З розміткою",
-    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
-    "Sequence" : "Послідовність",
-    "Result" : "Результат",
-    "Visualized" : "Візуалізація",
+    "Notes path" : "Шлях до нотаток",
+    "Folder to store your notes" : "Каталог для збереження нотаток",
+    "Root directory" : "Кореневий каталог",
+    "File extension" : "Розширення файлу",
+    "File extension for new notes" : "Розширення файлу для нових нотаток",
+    "Display mode" : "Режим перегляду",
+    "Display mode for notes" : "Показувати нотатки",
     "Shortcuts" : "Скорочення",
     "Use shortcuts to quickly navigate this app." : "Використовуйте скорочення для швидкої навігації у цьому застосунку.",
     "Shortcut" : "Скорочення",
     "Action" : "Дія ",
     "Mobile apps" : "Мобільні застосунки",
+    "User defined" : "Визначений користувачем",
+    "Open in rich text mode" : "Відкрити у форматованому режимі",
+    "Open in edit mode" : "Відкривати у режимі редагування",
+    "Open in preview mode" : "Відкривати у режимі перегляду",
+    "CTRL" : "CTRL",
     "Make the selection bold" : "Зробити виділене грубим",
     "Make the selection italic" : "Зробити виділене курсивом",
     "Wrap the selection in quotes" : "Додати лапки до виділеного фрагменту",
+    "ALT" : "ALT",
     "The selection will be turned into monospace" : "Перетворити шрифт виділеного тексту у моноширинний",
     "Remove any styles from the selected text" : "Прибрати стилі з виділеного тексту",
     "Makes the current line a list element" : "Зробити рядок елементом списку",
     "Makes the current line a list element with a number" : "Зробити рядок елементом нумерованого списку",
     "Toggle heading for current line" : "Зробити рядок заголовком",
+    "SHIFT" : "SHIFT",
     "Set the current line as a big heading" : "Зробити рядок великим заголовком",
     "Insert link" : "Вставити посилання",
     "Insert image" : "Додати зображення",
     "Switch between editor and viewer" : "Перемкнути редактор та переглядач",
-    "bold" : "грубий",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
-    "italic" : "курсив",
-    "strikethrough" : "перекреслений",
-    "Big header" : "Великий заголовок",
-    "Medium header" : "Середній заголовок",
-    "Small header" : "Малий заголовок",
-    "Tiny header" : "Маленький заголовок",
-    "Generic list item" : "Елемент ненумерованого списку",
-    "Generic list" : "Ненумерований список",
-    "Numbered list" : "Нумерований список",
-    "Link title" : "Назва посилання",
-    "link" : "посилання",
-    "Image title" : "Назва зображення",
-    "image" : "зображення",
-    "This is a quote." : "Це цитата",
-    "quote" : "цитата",
-    "code" : "код",
-    "Multi line block code" : "Блочний код на кілька рядків",
-    "Notes settings" : "Налаштування",
-    "Folder to store your notes" : "Каталог для збереження нотаток",
-    "Root directory" : "Кореневий каталог",
-    "File extension for new notes" : "Розширення файлу для нових нотаток",
-    "Display mode for notes" : "Показувати нотатки",
-    "User defined" : "Визначений користувачем",
-    "Open in edit mode" : "Відкривати у режимі редагування",
-    "Open in preview mode" : "Відкривати у режимі перегляду",
-    "Create a sample note with markdown" : "Створити типову нотатку з розміткою",
+    "Select folder to link to" : "Виберіть каталог",
+    "All notes" : "Усі нотатки",
+    "Categories" : "Категорії",
+    "Create a sample note with Markdown" : "Створіть зразок примітки з Markdown",
     "No notes yet" : "Нотатки поки відсутні",
     "Upload image" : "Завантажити зображення",
     "Select an image" : "Виберіть зображення",
@@ -74,26 +61,20 @@ OC.L10N.register(
     "Wrong image" : "Недійсне зображення",
     "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали свого сервера.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть програму для свого мобільного телефону, щоб мати доступ до своїх нотаток звідусіль.",
-    "Android app: {notes} by {company}" : "Застосунок для Android: {notes} для {company}",
-    "iOS app: {notes} by {company}" : "Застосунок для iOS: {notes} для {company}",
-    "All notes" : "Усі нотатки",
-    "Categories" : "Категорії",
-    "Loading …" : "Завантаження...",
-    "Today" : "Сьогодні",
-    "Yesterday" : "Вчора",
-    "This week" : "Цього тижня",
-    "Last week" : "Минулого тижня",
-    "This month" : "Цього місяця",
-    "Last month" : "Минулого місяця",
-    "Rename" : "Перейменувати",
-    "Note's title" : "Назва нотатки",
+    "Android app: {notes}" : "Додаток для Android: {notes}",
+    "iOS app: {notes}" : "Додаток для iOS: {notes}",
+    "Rich text editor" : "Редактор з форматуванням",
+    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ви можете почати використовувати простий у користуванні редактор форматованого тексту, який дозволить вводити текст без службових символів позначення форматування.",
+    "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
+    "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
+    "Use rich editor" : "Використовувати редактор з форматуванням",
     "Details" : "Деталі",
     "Delete note" : "Вилучити нотатку",
     "Remove from favorites" : "Вилучено з улюбленого",
-    "Add to favorites" : "Додати до улюбленого",
+    "Add to favorites" : "Додати зірочку",
     "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
     "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
-    "Use version from server" : "Використовуйте версію з сервера",
+    "Use version from server" : "Використовуйте віддалену версію",
     "Use current version" : "Використовувати поточну версію",
     "Empty note" : "Порожня записка",
     "Write …" : "Напишіть…",
@@ -106,6 +87,15 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Не вдалося зберегти. Натисніть, щоб повторити спробу.",
     "Update conflict. Click for resolving manually." : "Конфлікт оновлень. Натисніть, щоб вирішити вручну.",
     "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
+    "Search for notes" : "Пошук нотаток",
+    "Loading …" : "Завантаження...",
+    "Find in all categories" : "Шукати в усіх категоріях",
+    "Today" : "Сьогодні",
+    "Yesterday" : "Вчора",
+    "This week" : "Цього тижня",
+    "Last week" : "Минулого тижня",
+    "This month" : "Цього місяця",
+    "Last month" : "Минулого місяця",
     "Category" : "Категорія",
     "Uncategorized" : "Некатегоризоване",
     "Set category" : "Встановити категорію",
@@ -114,8 +104,11 @@ OC.L10N.register(
     "Last modified: {date}" : "Остання зміна: {дата}",
     "Note has unsaved changes" : "Примітка містить незбережені зміни",
     "Subcategory" : "Підкатегорія",
+    "Click to edit title" : "Натисніть, щоб змінити заголовок",
     "_%n word_::_%n words_" : ["%n слово","%n слів","%n слів","%n слів"],
     "_%n character_::_%n characters_" : ["%n персонаж","%n персонажів","%n персонажів","%n персонажів"],
+    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Ви можете створювати підкатегорії із застосуванням \"/\" як роздільника між батьківською категорією та підкатегорією, наприклад. \"{parent}/{sub}\".",
     "Note not found." : "Примітка не знайдена.",
     "Note is locked." : "Примітка заблокована.",
