@@ -4,14 +4,19 @@ OC.L10N.register(
     "Notes" : "Ghi chép",
     "Error" : "Lỗi",
     "New note" : "Ghi chú mới",
-    "Help" : "Trợ giúp",
-    "Insert image" : "Chèn ảnh",
     "Display mode for notes" : "Chế độ hiển thị cho các ghi chú",
     "Open in edit mode" : "Mở trong chế độ chỉnh sửa",
     "Open in preview mode" : "Mở trong chế độ xem trước",
-    "No notes yet" : "Chưa có ghi chú",
+    "Insert image" : "Chèn ảnh",
     "All notes" : "Tất cả ghi chú",
     "Categories" : "Các hạng mục",
+    "No notes yet" : "Chưa có ghi chú",
+    "Details" : "Thông tin",
+    "Remove from favorites" : "Xóa khỏi ưa thích",
+    "Add to favorites" : "Thêm vào ưa thích",
+    "Use current version" : "Sử dụng phiên bản hiện tại",
+    "Edit" : "Chỉnh sửa",
+    "Preview" : "Xem trước",
     "Loading …" : "Đang tải...",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
@@ -19,13 +24,6 @@ OC.L10N.register(
     "Last week" : "Tuần trước",
     "This month" : "Tháng này",
     "Last month" : "Tháng trước",
-    "Rename" : "Đổi tên",
-    "Details" : "Thông tin",
-    "Remove from favorites" : "Xóa khỏi ưa thích",
-    "Add to favorites" : "Thêm vào ưa thích",
-    "Use current version" : "Sử dụng phiên bản hiện tại",
-    "Edit" : "Chỉnh sửa",
-    "Preview" : "Xem trước",
     "Category" : "Hạng mục",
     "Uncategorized" : "Chưa phân loại",
     "Tasks" : "Nhiệm vụ"
