@@ -4,43 +4,53 @@ declare(strict_types=1);
 
 namespace OCA\Notes\Controller;
 
+use OCA\Notes\Service\Note;
 use OCA\Notes\Service\NotesService;
-use OCA\Notes\Service\MetaService;
 use OCA\Notes\Service\SettingsService;
 
 use OCP\AppFramework\Controller;
-use OCP\AppFramework\Http\FileDisplayResponse;
-use OCP\IRequest;
-use OCP\IConfig;
-use OCP\IL10N;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\JSONResponse;
+use OCP\AppFramework\Http\StreamResponse;
+use OCP\Files\IMimeTypeDetector;
+use OCP\Files\Lock\ILock;
+use OCP\Files\Lock\ILockManager;
+use OCP\Files\Lock\LockContext;
+use OCP\IConfig;
+use OCP\IL10N;
+use OCP\IRequest;
 
 class NotesController extends Controller {
 	private NotesService $notesService;
-	private MetaService $metaService;
 	private SettingsService $settingsService;
+	private ILockManager $lockManager;
 	private Helper $helper;
 	private IConfig $settings;
 	private IL10N $l10n;
+	private IMimeTypeDetector $mimeTypeDetector;
+	private string $userId;
 
 	public function __construct(
 		string $AppName,
 		IRequest $request,
 		NotesService $notesService,
-		MetaService $metaService,
+		ILockManager $lockManager,
 		SettingsService $settingsService,
 		Helper $helper,
 		IConfig $settings,
-		IL10N $l10n
+		IL10N $l10n,
+		IMimeTypeDetector $mimeTypeDetector,
+		string $userId
 	) {
 		parent::__construct($AppName, $request);
 		$this->notesService = $notesService;
-		$this->metaService = $metaService;
 		$this->settingsService = $settingsService;
+		$this->lockManager = $lockManager;
 		$this->helper = $helper;
 		$this->settings = $settings;
 		$this->l10n = $l10n;
+		$this->mimeTypeDetector = $mimeTypeDetector;
+		$this->userId = $userId;
 	}
 
 	/**
@@ -208,7 +218,9 @@ class NotesController extends Controller {
 			$oldTitle = $note->getTitle();
 			$newTitle = $this->notesService->getTitleFromContent($note->getContent());
 			if ($oldTitle !== $newTitle) {
-				$note->setTitle($newTitle);
+				$this->inLockScope($note, function () use ($note, $newTitle) {
+					$note->setTitle($newTitle);
+				});
 			}
 			return $note->getTitle();
 		});
@@ -258,14 +270,18 @@ class NotesController extends Controller {
 
 				case 'title':
 					if ($title !== null) {
-						$note->setTitle($title);
+						$this->inLockScope($note, function () use ($note, $title) {
+							$note->setTitle($title);
+						});
 					}
 					$result = $note->getTitle();
 					break;
 
 				case 'category':
 					if ($category !== null) {
-						$note->setCategory($category);
+						$this->inLockScope($note, function () use ($note, $category) {
+							$note->setCategory($category);
+						});
 					}
 					$result = $note->getCategory();
 					break;
@@ -299,17 +315,20 @@ class NotesController extends Controller {
 	 * With help from: https://github.com/nextcloud/cookbook
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
-	 * @return JSONResponse|FileDisplayResponse
+	 * @return JSONResponse|StreamResponse
 	 */
-	public function getAttachment(int $noteid, string $path) {
+	public function getAttachment(int $noteid, string $path): Http\Response {
 		try {
 			$targetimage = $this->notesService->getAttachment(
 				$this->helper->getUID(),
 				$noteid,
 				$path
 			);
-			$headers = ['Content-Type' => $targetimage->getMimetype(), 'Cache-Control' => 'public, max-age=604800'];
-			return new FileDisplayResponse($targetimage, Http::STATUS_OK, $headers);
+			$response = new StreamResponse($targetimage->fopen('rb'));
+			$response->addHeader('Content-Disposition', 'attachment; filename="' . rawurldecode($targetimage->getName()) . '"');
+			$response->addHeader('Content-Type', $this->mimeTypeDetector->getSecureMimeType($targetimage->getMimeType()));
+			$response->addHeader('Cache-Control', 'public, max-age=604800');
+			return $response;
 		} catch (\Exception $e) {
 			$this->helper->logException($e);
 			return $this->helper->createErrorResponse($e, Http::STATUS_NOT_FOUND);
@@ -329,4 +348,16 @@ class NotesController extends Controller {
 			);
 		});
 	}
+
+	private function inLockScope(Note $note, callable $callback) {
+		$isRichText = $this->settingsService->get($this->userId, 'noteMode') === 'rich';
+		$lockContext = new LockContext(
+			$note->getFile(),
+			$isRichText ? ILock::TYPE_APP : ILock::TYPE_USER,
+			$isRichText ? 'text' : $this->userId
+		);
+		$this->lockManager->runInScope($lockContext, function () use ($callback) {
+			$callback();
+		});
+	}
 }
